Class: Google::Apis::JobsV3::Money

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/jobs_v3/classes.rb,
lib/google/apis/jobs_v3/representations.rb,
lib/google/apis/jobs_v3/representations.rb

Overview

Represents an amount of money with its currency type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Money

Returns a new instance of Money.



1800
1801
1802
# File 'lib/google/apis/jobs_v3/classes.rb', line 1800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#currency_codeString

The three-letter currency code defined in ISO 4217. Corresponds to the JSON property currencyCode

Returns:

  • (String)


1783
1784
1785
# File 'lib/google/apis/jobs_v3/classes.rb', line 1783

def currency_code
  @currency_code
end

#nanosFixnum

Number of nano (10^-9) units of the amount. The value must be between -999,999, 999 and +999,999,999 inclusive. If units is positive, nanos must be positive or zero. If units is zero, nanos can be positive, zero, or negative. If units is negative, nanos must be negative or zero. For example $-1.75 is represented as units=-1 and nanos=-750,000,000. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


1792
1793
1794
# File 'lib/google/apis/jobs_v3/classes.rb', line 1792

def nanos
  @nanos
end

#unitsFixnum

The whole units of the amount. For example if currencyCode is "USD", then 1 unit is one US dollar. Corresponds to the JSON property units

Returns:

  • (Fixnum)


1798
1799
1800
# File 'lib/google/apis/jobs_v3/classes.rb', line 1798

def units
  @units
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1805
1806
1807
1808
1809
# File 'lib/google/apis/jobs_v3/classes.rb', line 1805

def update!(**args)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @nanos = args[:nanos] if args.key?(:nanos)
  @units = args[:units] if args.key?(:units)
end